diff lisp/mule/mule-init.el @ 197:acd284d43ca1 r20-3b25

Import from CVS: tag r20-3b25
author cvs
date Mon, 13 Aug 2007 10:00:02 +0200
parents 3bb7ccffb0c0
children e45d5e7c476e
line wrap: on
line diff
--- a/lisp/mule/mule-init.el	Mon Aug 13 09:59:07 2007 +0200
+++ b/lisp/mule/mule-init.el	Mon Aug 13 10:00:02 2007 +0200
@@ -105,21 +105,24 @@
       (load (format "locale/%s/locale-start" lang) t t)))
 
   (when (current-language-environment)
     ;; Translate remaining args on command line using pathname-coding-system
     (loop for arg in-ref command-line-args-left do
-	  (setf arg (decode-coding-string arg pathname-coding-system)))
+	  (setf arg (decode-coding-string arg file-name-coding-system)))
 
     ;; rman seems to be incompatible with encoded text
     (setq Manual-use-rosetta-man nil)
     
     ;; Make sure ls -l output is readable by dired and encoded using
-    ;; pathname-coding-system
+    ;; file-name-coding-system
     (add-hook
      'dired-mode-hook
      (lambda ()
        (make-local-variable 'process-environment)
        (setenv "LC_MESSAGES" "C")
        (setenv "LC_TIME"     "C"))))
+
+  ;; Register avairable input methods by loading LEIM list file.
+  (load "leim-list.el" 'noerror 'nomessage 'nosuffix)
   )
 
 (add-hook 'before-init-hook 'init-mule)
@@ -105,21 +105,24 @@
 
   (when (current-language-environment)
-    ;; Translate remaining args on command line using pathname-coding-system
+    ;; Translate remaining args on command line using file-name-coding-system
     (loop for arg in-ref command-line-args-left do